import * as i0 from '@angular/core';
import { Directive, Component, ViewEncapsulation, ChangeDetectionStrategy, Input, NgModule } from '@angular/core';
import * as i1 from '@angular/cdk/table';
import { CdkTable, CDK_TABLE, _COALESCED_STYLE_SCHEDULER, _CoalescedStyleScheduler, STICKY_POSITIONING_LISTENER, CDK_TABLE_TEMPLATE, CdkCellDef, CdkHeaderCellDef, CdkFooterCellDef, CdkColumnDef, CdkHeaderCell, CdkFooterCell, CdkCell, CdkHeaderRowDef, CdkFooterRowDef, CdkRowDef, CdkHeaderRow, CDK_ROW_TEMPLATE, CdkFooterRow, CdkRow, CdkNoDataRow, CdkTextColumn, CdkTableModule } from '@angular/cdk/table';
import { _VIEW_REPEATER_STRATEGY, _RecycleViewRepeaterStrategy, _DisposeViewRepeaterStrategy } from '@angular/cdk/collections';

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Enables the recycle view repeater strategy, which reduces rendering latency. Not compatible with
 * tables that animate rows.
 */
class NgbRecycleRows {
}
NgbRecycleRows.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbRecycleRows, deps: [], target: i0.ɵɵFactoryTarget.Directive });
NgbRecycleRows.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbRecycleRows, selector: "ngb-table[recycleRows], table[ngb-table][recycleRows]", providers: [{ provide: _VIEW_REPEATER_STRATEGY, useClass: _RecycleViewRepeaterStrategy }], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbRecycleRows, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-table[recycleRows], table[ngb-table][recycleRows]',
                    providers: [{ provide: _VIEW_REPEATER_STRATEGY, useClass: _RecycleViewRepeaterStrategy }],
                }]
        }] });
/**
 * Wrapper for the CdkTable with Material design styles.
 */
class NgbTable extends CdkTable {
    constructor() {
        super(...arguments);
        /** Overrides the sticky CSS class set by the `CdkTable`. */
        this.stickyCssClass = 'ngb-table-sticky';
        /** Overrides the need to add position: sticky on every sticky cell element in `CdkTable`. */
        this.needsPositionStickyOnElement = false;
    }
}
NgbTable.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbTable, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbTable.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.11", type: NgbTable, selector: "ngb-table, table[ngb-table]", host: { properties: { "class.ngb-table-fixed-layout": "fixedLayout" }, classAttribute: "cdk-table" }, providers: [
        // TODO(michaeljamesparsons) Abstract the view repeater strategy to a directive API so this code
        //  is only included in the build if used.
        { provide: _VIEW_REPEATER_STRATEGY, useClass: _DisposeViewRepeaterStrategy },
        { provide: CdkTable, useExisting: NgbTable },
        { provide: CDK_TABLE, useExisting: NgbTable },
        { provide: _COALESCED_STYLE_SCHEDULER, useClass: _CoalescedStyleScheduler },
        // Prevent nested tables from seeing this table's StickyPositioningListener.
        { provide: STICKY_POSITIONING_LISTENER, useValue: null },
    ], exportAs: ["ngbTable"], usesInheritance: true, ngImport: i0, template: "\n  <ng-content select=\"caption\"></ng-content>\n  <ng-content select=\"colgroup, col\"></ng-content>\n  <ng-container headerRowOutlet></ng-container>\n  <ng-container rowOutlet></ng-container>\n  <ng-container noDataRowOutlet></ng-container>\n  <ng-container footerRowOutlet></ng-container>\n", isInline: true, directives: [{ type: i1.HeaderRowOutlet, selector: "[headerRowOutlet]" }, { type: i1.DataRowOutlet, selector: "[rowOutlet]" }, { type: i1.NoDataRowOutlet, selector: "[noDataRowOutlet]" }, { type: i1.FooterRowOutlet, selector: "[footerRowOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbTable, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-table, table[ngb-table]',
                    exportAs: 'ngbTable',
                    template: CDK_TABLE_TEMPLATE,
                    host: {
                        'class': 'cdk-table',
                        '[class.ngb-table-fixed-layout]': 'fixedLayout',
                    },
                    providers: [
                        // TODO(michaeljamesparsons) Abstract the view repeater strategy to a directive API so this code
                        //  is only included in the build if used.
                        { provide: _VIEW_REPEATER_STRATEGY, useClass: _DisposeViewRepeaterStrategy },
                        { provide: CdkTable, useExisting: NgbTable },
                        { provide: CDK_TABLE, useExisting: NgbTable },
                        { provide: _COALESCED_STYLE_SCHEDULER, useClass: _CoalescedStyleScheduler },
                        // Prevent nested tables from seeing this table's StickyPositioningListener.
                        { provide: STICKY_POSITIONING_LISTENER, useValue: null },
                    ],
                    encapsulation: ViewEncapsulation.None,
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                }]
        }] });

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Cell definition for the mat-table.
 * Captures the template of a column's data row cell as well as cell-specific properties.
 */
class NgbCellDef extends CdkCellDef {
}
NgbCellDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbCellDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbCellDef, selector: "[ngbCellDef]", providers: [{ provide: CdkCellDef, useExisting: NgbCellDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbCellDef]',
                    providers: [{ provide: CdkCellDef, useExisting: NgbCellDef }],
                }]
        }] });
/**
 * Header cell definition for the mat-table.
 * Captures the template of a column's header cell and as well as cell-specific properties.
 */
class NgbHeaderCellDef extends CdkHeaderCellDef {
}
NgbHeaderCellDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbHeaderCellDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbHeaderCellDef, selector: "[ngbHeaderCellDef]", providers: [{ provide: CdkHeaderCellDef, useExisting: NgbHeaderCellDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbHeaderCellDef]',
                    providers: [{ provide: CdkHeaderCellDef, useExisting: NgbHeaderCellDef }],
                }]
        }] });
/**
 * Footer cell definition for the mat-table.
 * Captures the template of a column's footer cell and as well as cell-specific properties.
 */
class NgbFooterCellDef extends CdkFooterCellDef {
}
NgbFooterCellDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbFooterCellDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbFooterCellDef, selector: "[ngbFooterCellDef]", providers: [{ provide: CdkFooterCellDef, useExisting: NgbFooterCellDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbFooterCellDef]',
                    providers: [{ provide: CdkFooterCellDef, useExisting: NgbFooterCellDef }],
                }]
        }] });
/**
 * Column definition for the mat-table.
 * Defines a set of cells available for a table column.
 */
class NgbColumnDef extends CdkColumnDef {
    /** Unique name for this column. */
    get name() {
        return this._name;
    }
    set name(name) {
        this._setNameInput(name);
    }
    /**
     * Add "mat-column-" prefix in addition to "cdk-column-" prefix.
     * In the future, this will only add "mat-column-" and columnCssClassName
     * will change from type string[] to string.
     * @docs-private
     */
    _updateColumnCssClassName() {
        super._updateColumnCssClassName();
        this._columnCssClassName.push(`ngb-column-${this.cssClassFriendlyName}`);
    }
}
NgbColumnDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbColumnDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbColumnDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbColumnDef, selector: "[ngbColumnDef]", inputs: { sticky: "sticky", name: ["ngbColumnDef", "name"] }, providers: [
        { provide: CdkColumnDef, useExisting: NgbColumnDef },
        { provide: 'NGB_SORT_HEADER_COLUMN_DEF', useExisting: NgbColumnDef },
    ], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbColumnDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbColumnDef]',
                    inputs: ['sticky'],
                    providers: [
                        { provide: CdkColumnDef, useExisting: NgbColumnDef },
                        { provide: 'NGB_SORT_HEADER_COLUMN_DEF', useExisting: NgbColumnDef },
                    ],
                }]
        }], propDecorators: { name: [{
                type: Input,
                args: ['ngbColumnDef']
            }] } });
/** Header cell template container that adds the right classes and role. */
class NgbHeaderCell extends CdkHeaderCell {
}
NgbHeaderCell.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderCell, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbHeaderCell.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbHeaderCell, selector: "ngb-header-cell, th[ngb-header-cell]", host: { attributes: { "role": "columnheader" }, classAttribute: "cdk-header-cell" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-header-cell, th[ngb-header-cell]',
                    host: {
                        'class': 'cdk-header-cell',
                        'role': 'columnheader',
                    },
                }]
        }] });
/** Footer cell template container that adds the right classes and role. */
class NgbFooterCell extends CdkFooterCell {
}
NgbFooterCell.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterCell, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbFooterCell.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbFooterCell, selector: "ngb-footer-cell, td[ngb-footer-cell]", host: { attributes: { "role": "gridcell" }, classAttribute: "cdk-footer-cell" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-footer-cell, td[ngb-footer-cell]',
                    host: {
                        'class': 'cdk-footer-cell',
                        'role': 'gridcell',
                    },
                }]
        }] });
/** Cell template container that adds the right classes and role. */
class NgbCell extends CdkCell {
}
NgbCell.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbCell, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbCell.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbCell, selector: "ngb-cell, td[ngb-cell]", host: { attributes: { "role": "gridcell" }, classAttribute: "cdk-cell" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-cell, td[ngb-cell]',
                    host: {
                        'class': 'cdk-cell',
                        'role': 'gridcell',
                    },
                }]
        }] });

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Header row definition for the mat-table.
 * Captures the header row's template and other header properties such as the columns to display.
 */
class NgbHeaderRowDef extends CdkHeaderRowDef {
}
NgbHeaderRowDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbHeaderRowDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbHeaderRowDef, selector: "[ngbHeaderRowDef]", inputs: { columns: ["ngbHeaderRowDef", "columns"], sticky: ["ngbHeaderRowDefSticky", "sticky"] }, providers: [{ provide: CdkHeaderRowDef, useExisting: NgbHeaderRowDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbHeaderRowDef]',
                    providers: [{ provide: CdkHeaderRowDef, useExisting: NgbHeaderRowDef }],
                    inputs: ['columns: ngbHeaderRowDef', 'sticky: ngbHeaderRowDefSticky'],
                }]
        }] });
/**
 * Footer row definition for the mat-table.
 * Captures the footer row's template and other footer properties such as the columns to display.
 */
class NgbFooterRowDef extends CdkFooterRowDef {
}
NgbFooterRowDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbFooterRowDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbFooterRowDef, selector: "[ngbFooterRowDef]", inputs: { columns: ["ngbFooterRowDef", "columns"], sticky: ["ngbFooterRowDefSticky", "sticky"] }, providers: [{ provide: CdkFooterRowDef, useExisting: NgbFooterRowDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbFooterRowDef]',
                    providers: [{ provide: CdkFooterRowDef, useExisting: NgbFooterRowDef }],
                    inputs: ['columns: ngbFooterRowDef', 'sticky: ngbFooterRowDefSticky'],
                }]
        }] });
/**
 * Data row definition for the mat-table.
 * Captures the data row's template and other properties such as the columns to display and
 * a when predicate that describes when this row should be used.
 */
class NgbRowDef extends CdkRowDef {
}
NgbRowDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbRowDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbRowDef, selector: "[ngbRowDef]", inputs: { columns: ["ngbRowDefColumns", "columns"], when: ["ngbRowDefWhen", "when"] }, providers: [{ provide: CdkRowDef, useExisting: NgbRowDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbRowDef]',
                    providers: [{ provide: CdkRowDef, useExisting: NgbRowDef }],
                    inputs: ['columns: ngbRowDefColumns', 'when: ngbRowDefWhen'],
                }]
        }] });
/** Header template container that contains the cell outlet. Adds the right class and role. */
class NgbHeaderRow extends CdkHeaderRow {
}
NgbHeaderRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderRow, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbHeaderRow.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.11", type: NgbHeaderRow, selector: "ngb-header-row, tr[ngb-header-row]", host: { attributes: { "role": "row" } }, providers: [{ provide: CdkHeaderRow, useExisting: NgbHeaderRow }], exportAs: ["ngbHeaderRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, directives: [{ type: i1.CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbHeaderRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-header-row, tr[ngb-header-row]',
                    template: CDK_ROW_TEMPLATE,
                    host: {
                        //'class': 'ngb-header-row',
                        'role': 'row',
                    },
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbHeaderRow',
                    providers: [{ provide: CdkHeaderRow, useExisting: NgbHeaderRow }],
                }]
        }] });
/** Footer template container that contains the cell outlet. Adds the right class and role. */
class NgbFooterRow extends CdkFooterRow {
}
NgbFooterRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterRow, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbFooterRow.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.11", type: NgbFooterRow, selector: "ngb-footer-row, tr[ngb-footer-row]", host: { attributes: { "role": "row" }, classAttribute: "cdk-footer-row" }, providers: [{ provide: CdkFooterRow, useExisting: NgbFooterRow }], exportAs: ["ngbFooterRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, directives: [{ type: i1.CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbFooterRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-footer-row, tr[ngb-footer-row]',
                    template: CDK_ROW_TEMPLATE,
                    host: {
                        'class': 'cdk-footer-row',
                        'role': 'row',
                    },
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbFooterRow',
                    providers: [{ provide: CdkFooterRow, useExisting: NgbFooterRow }],
                }]
        }] });
/** Data row template container that contains the cell outlet. Adds the right class and role. */
class NgbRow extends CdkRow {
}
NgbRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbRow, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbRow.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.11", type: NgbRow, selector: "ngb-row, tr[ngb-row]", host: { attributes: { "role": "row" }, classAttribute: "cdk-row" }, providers: [{ provide: CdkRow, useExisting: NgbRow }], exportAs: ["ngbRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, directives: [{ type: i1.CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-row, tr[ngb-row]',
                    template: CDK_ROW_TEMPLATE,
                    host: {
                        'class': 'cdk-row',
                        'role': 'row',
                    },
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbRow',
                    providers: [{ provide: CdkRow, useExisting: NgbRow }],
                }]
        }] });
/** Row that can be used to display a message when no data is shown in the table. */
class NgbNoDataRow extends CdkNoDataRow {
}
NgbNoDataRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbNoDataRow, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbNoDataRow.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.11", type: NgbNoDataRow, selector: "ng-template[ngbNoDataRow]", providers: [{ provide: CdkNoDataRow, useExisting: NgbNoDataRow }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbNoDataRow, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[ngbNoDataRow]',
                    providers: [{ provide: CdkNoDataRow, useExisting: NgbNoDataRow }],
                }]
        }] });

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Column that simply shows text content for the header and row cells. Assumes that the table
 * is using the native table implementation (`<table>`).
 *
 * By default, the name of this column will be the header text and data property accessor.
 * The header text can be overridden with the `headerText` input. Cell values can be overridden with
 * the `dataAccessor` input. Change the text justification to the start or end using the `justify`
 * input.
 */
class NgbTextColumn extends CdkTextColumn {
}
NgbTextColumn.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbTextColumn, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbTextColumn.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.11", type: NgbTextColumn, selector: "ngb-text-column", usesInheritance: true, ngImport: i0, template: `
    <ng-container ngbColumnDef>
      <th ngb-header-cell *ngbHeaderCellDef [style.text-align]="justify">
        {{headerText}}
      </th>
      <td ngb-cell *ngbCellDef="let data" [style.text-align]="justify">
        {{dataAccessor(data, name)}}
      </td>
    </ng-container>
  `, isInline: true, directives: [{ type: NgbColumnDef, selector: "[ngbColumnDef]", inputs: ["sticky", "ngbColumnDef"] }, { type: NgbHeaderCellDef, selector: "[ngbHeaderCellDef]" }, { type: NgbHeaderCell, selector: "ngb-header-cell, th[ngb-header-cell]" }, { type: NgbCellDef, selector: "[ngbCellDef]" }, { type: NgbCell, selector: "ngb-cell, td[ngb-cell]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: NgbTextColumn, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-text-column',
                    template: `
    <ng-container ngbColumnDef>
      <th ngb-header-cell *ngbHeaderCellDef [style.text-align]="justify">
        {{headerText}}
      </th>
      <td ngb-cell *ngbCellDef="let data" [style.text-align]="justify">
        {{dataAccessor(data, name)}}
      </td>
    </ng-container>
  `,
                    encapsulation: ViewEncapsulation.None,
                    // Change detection is intentionally not set to OnPush. This component's template will be provided
                    // to the table to be inserted into its view. This is problematic when change detection runs since
                    // the bindings in this template will be evaluated _after_ the table's view is evaluated, which
                    // mean's the template in the table's view will not have the updated value (and in fact will cause
                    // an ExpressionChangedAfterItHasBeenCheckedError).
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                }]
        }] });

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
const EXPORTED_DECLARATIONS = [
    // Table
    NgbTable,
    NgbRecycleRows,
    // Template defs
    NgbHeaderCellDef,
    NgbHeaderRowDef,
    NgbColumnDef,
    NgbCellDef,
    NgbRowDef,
    NgbFooterCellDef,
    NgbFooterRowDef,
    // Cell directives
    NgbHeaderCell,
    NgbCell,
    NgbFooterCell,
    // Row directives
    NgbHeaderRow,
    NgbRow,
    NgbFooterRow,
    NgbNoDataRow,
    NgbTextColumn,
];
class DfxTableModule {
}
DfxTableModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: DfxTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DfxTableModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: DfxTableModule, declarations: [
        // Table
        NgbTable,
        NgbRecycleRows,
        // Template defs
        NgbHeaderCellDef,
        NgbHeaderRowDef,
        NgbColumnDef,
        NgbCellDef,
        NgbRowDef,
        NgbFooterCellDef,
        NgbFooterRowDef,
        // Cell directives
        NgbHeaderCell,
        NgbCell,
        NgbFooterCell,
        // Row directives
        NgbHeaderRow,
        NgbRow,
        NgbFooterRow,
        NgbNoDataRow,
        NgbTextColumn], imports: [CdkTableModule], exports: [
        // Table
        NgbTable,
        NgbRecycleRows,
        // Template defs
        NgbHeaderCellDef,
        NgbHeaderRowDef,
        NgbColumnDef,
        NgbCellDef,
        NgbRowDef,
        NgbFooterCellDef,
        NgbFooterRowDef,
        // Cell directives
        NgbHeaderCell,
        NgbCell,
        NgbFooterCell,
        // Row directives
        NgbHeaderRow,
        NgbRow,
        NgbFooterRow,
        NgbNoDataRow,
        NgbTextColumn] });
DfxTableModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: DfxTableModule, imports: [[CdkTableModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.11", ngImport: i0, type: DfxTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CdkTableModule],
                    exports: [EXPORTED_DECLARATIONS],
                    declarations: EXPORTED_DECLARATIONS,
                }]
        }] });

/*
 * Public API Surface of dfx-bootstrap-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DfxTableModule, NgbCell, NgbCellDef, NgbColumnDef, NgbFooterCell, NgbFooterCellDef, NgbFooterRow, NgbFooterRowDef, NgbHeaderCell, NgbHeaderCellDef, NgbHeaderRow, NgbHeaderRowDef, NgbNoDataRow, NgbRecycleRows, NgbRow, NgbRowDef, NgbTable, NgbTextColumn };
//# sourceMappingURL=dfx-bootstrap-table.js.map
